#!/bin/python
import tarfile
import argparse
import os

def backup_to_tarball(source_path, target_tarball):
    with tarfile.open(target_tarball, "w:gz") as tar:
        tar.add(source_path, arcname=os.path.basename(source_path))

def restore_from_tarball(source_tarball, target_path):
    with tarfile.open(source_tarball, "r:gz") as tar:
        tar.extractall(path=target_path)

def main(): 
    parser = argparse.ArgumentParser(description='Backup a path to a tarball')
    
    parser.add_argument('mode', choices=['backup', 'restore'], help='Mode: backup or restore')

    parser.add_argument('source_path', help='Path to the source directory or tarball')
    
    parser.add_argument('target_path', help='Path to the target directory or tarball')
    
    args = parser.parse_args()
    
    if args.mode == 'backup':
        backup_to_tarball(args.source_path, args.target_path)
    elif args.mode == 'restore':
        restore_from_tarball(args.source_path, args.target_path)

if __name__ == "__main__":
    main()

